#!/usr/bin/python

from utils import *

class DelayedTests(IloTestCase):
    def test_delayed_calls(self, ilo):
        uid = {'ON': 'Yes', 'OFF': 'No'}[ilo.get_uid_status()]
        non_delayed = [
            ilo.get_all_users(),
            ilo.get_global_settings(),
        ]
        try:
            ilo.delayed = True
            ilo.get_all_users()
            ilo.uid_control(uid=uid)
            ilo.get_global_settings()
            delayed = ilo.call_delayed()
        finally:
            ilo.delayed = False
        self.assertEquals(non_delayed, delayed)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python

from utils import *

class UidTests(IloTestCase):
    def test_uid(self, ilo):
        old = ilo.get_uid_status()
        new = {'ON': 'No', 'OFF': 'Yes'}[old]
        new2 = {'ON': 'OFF', 'OFF': 'ON'}[old]
        try:
            ilo.uid_control(uid=new)
            self.assertEqual(new2, ilo.get_uid_status())
        finally:
            ilo.uid_control(uid=old)

if __name__ == '__main__':
    unittest.main()



import unittest
import ConfigParser
import json
import os
import sys
import time
import re

testroot = os.path.dirname(__file__)
sys.path.insert(0, os.path.dirname(testroot))

import hpilo
import warnings
warnings.filterwarnings("ignore", category=hpilo.IloWarning)

class FirmwareCache(object):
    def __init__(self):
        self.cachefile = os.path.join(testroot, '.firmware_version_cache')
        self.cache = {}
        if os.path.exists(self.cachefile):
            with open(self.cachefile) as fd:
                self.cache = json.load(fd)

    def __getitem__(self, ilo):
        if ilo.hostname not in self.cache:
            self.cache[ilo.hostname] = ilo.get_fw_version()
            with open(self.cachefile, 'w') as fd:
                json.dump(self.cache, fd)
        return self.cache[ilo.hostname]
firmware_cache = FirmwareCache()

class IloTestCaseMeta(type):
    def __new__(cls, name, bases, attrs):
        attrs['ilos'] = {}
        config = ConfigParser.ConfigParser()
        config.read(os.path.expanduser(os.path.join('~', '.ilo.conf')))
        login = config.get('ilo', 'login')
        password = config.get('ilo', 'password')
        methods = []
        for attr in list(attrs.keys()):
            if attr.startswith('test_') and callable(attrs[attr]):
                attrs['_' + attr] = attrs.pop(attr)
                methods.append(attr[5:])

        for section in config.sections():
            if not section.startswith('test '):
                continue
            key = section.split()[1]
            hostname = config.get(section, 'ilo')
            ilo = hpilo.Ilo(hostname, login, password)
            ilo.firmware_version = firmware_cache[ilo]
            if not ilo.protocol:
                ilo.protocol = hpilo.ILO_RAW if ilo.firmware_version['management_processor'].lower() in ('ilo', 'ilo2') else hpilo.ILO_HTTP

            ilo.save_response = os.path.join(testroot, 'hpilo_test_debug_output')
            attrs['ilos'][key] = ilo
            for method in methods:
                fname = re.sub('[^a-zA-Z0-9_]', '_', 'test_%s_%s' % (key, method))
                attrs[fname] = eval("lambda self: self._test_%s(self.ilos['%s'])" % (method, key))
        return super(IloTestCaseMeta, cls).__new__(cls, name, bases, attrs)

class IloTestCase(unittest.TestCase):
    __metaclass__ = IloTestCaseMeta
    maxDiff = None

    def require_ilo(self, ilo, *ilos):
        for ilov in ilos:
            version = None
            if ':' in ilov:
                ilov, version = ilov.split(':')
            if ilo.firmware_version['management_processor'].lower() == ilov:
                if not version or ilo.firmware_version['firmware_version'] >= version:
                    return True

        raise unittest.SkipTest("This test requires %s, not %s:%s" % ('|'.join(ilos), 
            ilo.firmware_version['management_processor'].lower(), ilo.firmware_version['firmware_version']))

    def reset_delay(self, ilo):
        time.sleep(30)
        while True:
            try:
                ilo.get_fw_version()
                return
            except hpilo.IloCommunicationError:
                time.sleep(10)



#!/usr/bin/python

from utils import *

class GlobalSettingsTests(IloTestCase):
    def test_mod_global_settings(self, ilo):
        old = ilo.get_global_settings()
        try:
            ilo.mod_global_settings(
                f8_login_required=True,
                min_password=3
            )
            new = ilo.get_global_settings()
            self.assertEqual(new['f8_login_required'], True)
            self.assertEqual(new['min_password'], 3)
        finally:
            ilo.mod_global_settings(
                f8_login_required=old['f8_login_required'],
                min_password=old['min_password']
            )

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python

from utils import *
import pprint

class ResponsesTestMeta(type):
    def __new__(cls, name, parents, attrs):
        root = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'xml')
        for machine in os.listdir(root):
            mdir = os.path.join(root, machine)
            if not os.path.isdir(mdir):
                continue

            files = os.listdir(mdir)
            for rawfile in files:
                if not rawfile.endswith('.raw'):
                    continue
                method = rawfile.replace('.raw', '')
                parsedfile = rawfile.replace('.raw', '.parsed')
                rawpath = os.path.join(mdir, rawfile)
                parsedpath = os.path.join(mdir, parsedfile)
                fname = 'test_%s_%s' % (machine, method)
                fname = re.sub('[^a-zA-Z_0-9]', '_', fname).lower()
                attrs[fname] = eval("lambda self: self._test_response('%s', '%s', '%s', '%s')" % 
                                    (machine, method, rawpath, parsedpath))
        return super(ResponsesTestMeta, cls).__new__(cls, name, parents, attrs)

class ResponsesTest(unittest.TestCase):
    __metaclass__ = ResponsesTestMeta
    maxDiff = None
    method_args = {
        'get_user': ['Administrator'],
        'get_federation_group': ['slartibartfast'],
    }
    def _test_response(self, machine, method, rawfile, parsedfile):
        ilo = hpilo.Ilo('nonexistent-machine','Administrator','TestPassword')
        if 'ilo3' in machine.lower() or 'ilo4' in machine.lower():
            ilo.protocol = hpilo.ILO_HTTP
        else:
            ilo.protocol = hpilo.ILO_RAW
        ilo.read_response = rawfile

        args = self.method_args.get(method, [])
        if not os.path.exists(parsedfile):
            self.assertRaises(hpilo.IloError, getattr(ilo, method), *args)
            return
        response = getattr(ilo, method)(*args)
        new = pprint.pformat(response) + '\n'
        with open(parsedfile) as fd:
            old = fd.read()
        self.assertMultiLineEqual(old, new)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python

from utils import *

class RequestsTestMeta(type):
    def __new__(cls, name, parents, attrs):
        root = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'xml')
        for machine in os.listdir(root):
            mdir = os.path.join(root, machine)
            if not os.path.isdir(mdir):
                continue

            files = os.listdir(mdir)
            for argsfile in files:
                if not argsfile.endswith('.args'):
                    continue
                method = argsfile[:argsfile.find('-')]
                reqfile = argsfile.replace('.args', '.request')
                reqtmpfile = argsfile.replace('.args', '.request.tmp')
                argspath = os.path.join(mdir, argsfile)
                reqpath = os.path.join(mdir, reqfile)
                reqtmppath = os.path.join(mdir, reqtmpfile)
                fname = 'test_%s_%s' % (machine, argsfile[:-5])
                fname = re.sub('[^a-zA-Z_0-9]', '_', fname).lower()
                attrs[fname] = eval("lambda self: self._test_request('%s', '%s', '%s', '%s', '%s')" % 
                                    (machine, method, argspath, reqpath, reqtmppath))
        return super(RequestsTestMeta, cls).__new__(cls, name, parents, attrs)

class RequestsTest(unittest.TestCase):
    __metaclass__ = RequestsTestMeta
    maxDiff = None

    def _test_request(self, machine, method, argsfile, reqfile, reqtmpfile):
        ilo = hpilo.Ilo('nonexistent-machine','Administrator','TestPassword')
        if 'ilo3' in machine.lower() or 'ilo4' in machine.lower():
            ilo.protocol = hpilo.ILO_HTTP
        else:
            ilo.protocol = hpilo.ILO_RAW
        if os.path.exists(reqtmpfile):
            os.unlink(reqtmpfile)
        ilo.save_request = reqtmpfile
        with open(argsfile) as fd:
            args, kwargs = eval(fd.read()), {}
        if isinstance(args, dict):
            args, kwargs = [], args

        if not os.path.exists(reqfile):
            self.assertRaises(ValueError, getattr(ilo, method), *args, **kwargs)
            return

        getattr(ilo, method)(*args, **kwargs)
        with open(reqfile) as fd:
            old = fd.read()
        with open(reqtmpfile) as fd:
            new = fd.read()
        self.assertMultiLineEqual(old, new)
        os.unlink(reqtmpfile)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python

from utils import *
import time

class LogTests(IloTestCase):
    def test_ilo_event_log(self, ilo):
        ilo.clear_ilo_event_log()
        time.sleep(2)
        log = ilo.get_ilo_event_log()
        self.assertTrue(type(log) != dict)
        self.assertTrue(len(log) <= 3)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python

from utils import *
import random

class BootTests(IloTestCase):
    def test_persistent_boot(self, ilo):
        old = ilo.get_persistent_boot()
        new = old[:]
        random.shuffle(new)
        try:
            ilo.set_persistent_boot(new)
            self.assertEqual(new, ilo.get_persistent_boot())
        finally:
            ilo.set_persistent_boot(old)

    def test_one_time_boot(self, ilo):
        old = ilo.get_one_time_boot()
        all = ilo.get_persistent_boot()
        if old in all:
            all.remove(old)
        new = random.choice(all)
        try:
            ilo.set_one_time_boot(new)
            self.assertEqual(new, ilo.get_one_time_boot())
        finally:
            ilo.set_one_time_boot(old)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python

from utils import *

class LanguageTests(IloTestCase):
    def test_languages(self, ilo):
        ilo.set_language(ilo.get_language()['lang_id'])

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python

from utils import *
import random

class UserTests(IloTestCase):
    test_user_login = 'ilotestuser'

    @classmethod
    def setUpClass(cls):
        for ilo in cls.ilos.values():
            try:
                ilo.delete_user(cls.test_user_login)
            except hpilo.IloUserNotFound:
                pass
    tearDownClass = setUpClass

    def test_user_creation(self, ilo):
        alphabet = 'abcdefghijklmnopqrstuvwxyz'
        alphabet += alphabet.upper()
        password = ''.join([random.choice(alphabet) for i in range(random.randint(20,30))])
        ilo.add_user(self.test_user_login, 'python-hpilo test user', password,
                     admin_priv=False, remote_cons_priv=False, reset_server_priv=False,
                     virtual_media_priv=False, config_ilo_priv=False)
        user = ilo.get_user(self.test_user_login)
        self.assertFalse(user['admin_priv'])
        self.assertFalse(user['remote_cons_priv'])

    def test_user_manipulation(self, ilo):
        ilo.mod_user(self.test_user_login, remote_cons_priv=True)
        user = ilo.get_user(self.test_user_login)
        self.assertFalse(user['admin_priv'])
        self.assertTrue(user['remote_cons_priv'])

    def test_user_ssh_keys(self, ilo):
        ssh_key = ''.join(['ssh-dss AAAAB3NzaC1kc3MAAACBAIpNY5fvLSS3MCjGNKjuWH',
                           'rFGR5J6vLqdqIrXttTz7o6GWtmyxcC0Mlp2c/h1bMfvUiKDvDp',
                           '+5T7SGo/2R+aXLaPwYtm6eBPEBU2CgVTnpeVELDeaJ/tr0kTL/',
                           'PKMHZDFgT9c7/hOiWr4amlGvuxs60MP/xs4jWaxLxabhjiRoCL',
                           'AAAAFQChDEFySo74rpPNNWfvJHgiylTbRQAAAIEAgo8UQqXP7g',
                           'MTAUdHTqlzoTnj3loc4ZTnf3W6jr25cs5XaXNnRtadfw0G4VWa',
                           'S/uDyNhsq/o2nFrhWTwAvojWSe4C5MDdGGerktL1ZY/QfoxB0d',
                           '7aK/dlHd1iOVpGahCqyzmhEDmEnq6TWd6cBVHNVcryLEJVVtaf',
                           '8QmJlwS+XkIAAACAJGnuO6ZJ1S2AMOY1uOpov/srTyuu6Pxtcn',
                           'HsHA5wNoNQFcYElnDndJUfMAPi0vzODntHoiOGdrX3RcjxSAB5',
                           'lAgNZwFnwGWoAa8UIQlX+GwDYAIk+8G36tmHRgtl7xJlFqs9W6',
                           'BhrJEmfL4ubWCPXl/yMDrrLnMQuV3Mg0DNVSg= Test key'])
        ilo.import_ssh_key(self.test_user_login, ssh_key)
        ilo.delete_ssh_key(self.test_user_login)

    def test_z_user_deletion(self, ilo):
        ilo.delete_user(self.test_user_login)
        self.assertRaises(hpilo.IloUserNotFound, ilo.get_user, self.test_user_login)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python

from utils import *

class NetworkTests(IloTestCase):
    def test_mod_network_settings(self, ilo):
        old = ilo.get_network_settings()
        try:
            ilo.mod_network_settings(ter_dns_server='10.1.1.1')
            self.reset_delay(ilo)
            new = ilo.get_network_settings()
            self.assertEquals(new['ter_dns_server'], '10.1.1.1')
        finally:
            ilo.mod_network_settings(ter_dns_server='' if old['ter_dns_server'] == '0.0.0.0' else old['ter_dns_server'])
            self.reset_delay(ilo)

    def test_ipv6_routes(self, ilo):
        self.require_ilo(ilo, 'ilo3:1.50', 'ilo4:1.20')

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python

from utils import *

class SnmpTests(IloTestCase):
    def test_mod_snmp_im_settings(self, ilo):
        old = ilo.get_snmp_im_settings()
        try:
            ilo.mod_snmp_im_settings(snmp_address_3='10.42.42.42', rib_traps=True)
            new = ilo.get_snmp_im_settings()
            self.assertEqual(new['snmp_address_3'], '10.42.42.42')
            self.assertEqual(new['rib_traps'], True)
        finally:
            ilo.mod_snmp_im_settings(snmp_address_3=old['snmp_address_3'], rib_traps=old['rib_traps'])

    def test_snmp_user_profiles(self, ilo):
        self.require_ilo(ilo, 'ilo4')

if __name__ == '__main__':
    unittest.main()
